@@ -53,7 +53,7 @@ sub expand
     $strarr = [ @$strarr ];
     foreach $i (@$strarr)
     {
-      $i = &expand ($i, $substr, $value);
+      $i = &expand ($i, @args);
     }
 
     return $strarr;
@@ -408,8 +408,11 @@ sub split_all_array_with_pos
 
   foreach $i (@$arr)
   {
-    @s = split ($sep, $i);
-    push @ret, @s[0];
+    if ($i)
+    {
+      @s = split ($sep, $i);
+      push @ret, @s[0];
+    }
   }
 
   return \@ret;
@@ -563,9 +566,9 @@ sub unescape
 sub escape
 {
   my ($value) = @_;
-  
-  $value =~ s/([\"\`\$\\])/\\$1/g;
-  $value = "\"$value\"" if ($value =~ /[ \t\'&|*?\[\]\{\}\{\}<>]/);
+
+  $value =~ s/([\ \"\`\$\\])/\\$1/g;
+  #$value = "\"$value\"" if ($value =~ /[ \t\'&|*?\[\]\{\}\{\}<>]/);
 
   return $value;
 }
@@ -737,6 +740,8 @@ sub get_from_chatfile
     chomp;
     while ($_ ne "")
     {
+      s/^\s*//;
+
       # If it uses quotes. FIXME: Assuming they surround the whole string.
       if (/^\'/)
       {
@@ -745,10 +750,10 @@ sub get_from_chatfile
       }
       else
       {
-        s/([^ \t]*) ?//;
+        s/(\S*)\s?//;
         $found = $1;
       }
-      
+
       # If it looks like what we're looking for, return what matched the parens.
       if ($found =~ /$re/i)
       {
@@ -832,7 +837,7 @@ sub get_from_ini
   &Utils::Report::leave ();
   $res = undef;
   $escaped_section = &escape ($section);
-  
+
   while (($line = &ini_line_read ($fd)) != -1)
   {
     $_ = $$line;
